aboutsummaryrefslogtreecommitdiff
path: root/cast/sender/public
diff options
context:
space:
mode:
Diffstat (limited to 'cast/sender/public')
-rw-r--r--cast/sender/public/README.md2
-rw-r--r--cast/sender/public/cast_app_discovery_service.h6
2 files changed, 4 insertions, 4 deletions
diff --git a/cast/sender/public/README.md b/cast/sender/public/README.md
index b670d110..eb7527f5 100644
--- a/cast/sender/public/README.md
+++ b/cast/sender/public/README.md
@@ -1,5 +1,5 @@
# cast/sender/public
This module contains an implementation of the Cast "sender", i.e. the client
-that discovers Cast devices on the LAN and launches apps on them.
+that discovers Cast receivers on the LAN and launches apps on them.
diff --git a/cast/sender/public/cast_app_discovery_service.h b/cast/sender/public/cast_app_discovery_service.h
index f85e35b1..2e095b6d 100644
--- a/cast/sender/public/cast_app_discovery_service.h
+++ b/cast/sender/public/cast_app_discovery_service.h
@@ -14,12 +14,12 @@ namespace cast {
class CastMediaSource;
// Interface for app discovery for Cast devices.
class CastAppDiscoveryService {
public:
using AvailabilityCallback =
std::function<void(const CastMediaSource& source,
- const std::vector<ReceiverInfo>& devices)>;
+ const std::vector<ReceiverInfo>& receivers)>;
class Subscription {
public:
@@ -47,7 +47,7 @@ class CastAppDiscoveryService {
// returned via |callback| until the returned Subscription is destroyed by the
// caller. If there are cached results available, |callback| will be invoked
// before this method returns. |callback| may be invoked with an empty list
- // if all devices respond to the respective queries with "unavailable" or
+ // if all receivers respond to the respective queries with "unavailable" or
// don't respond before a timeout. |callback| may be invoked successively
// with the same list.
virtual Subscription StartObservingAvailability(
@@ -14,12 +14,12 @@ namespace cast {
class CastMediaSource;
-// Interface for app discovery for Cast devices.
+// Interface for app discovery for Cast receivers.
class CastAppDiscoveryService {
public: